require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module OrganizationalUnit
      class OrganizationalUnitAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the organizational unit. Never nil.
        attr_accessor :uri

        # Name of the organizational unit. Never nil.
        attr_accessor :name

        # Code of the organizational unit. Never nil.
        attr_accessor :code

        # Description of the organizational unit. Never nil.
        attr_accessor :description

        # URI of the organizational unit's container. Returns nil if the organizational
        # unit is the root of a territory (therefore there is no superior folder, organizational
        # unit etc.).
        attr_accessor :location_uri

        # URI of the parent organizational unit. Returns nil if the organizational unit
        # is the root of a territory (therefore there is no superior organizational unit).
        attr_accessor :organizational_unit_uri

        # URI of the company where the organizational unit is located.
        # @deprecated
        attr_accessor :company_uri

        # URI of the meta artifact. Never nil.
        attr_accessor :meta_artifact_uri

        # URI of the competent role. Never nil.
        attr_accessor :competent_role_uri

        # Security level of the organizational unit. Never nil.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # Creation stamp of the organizational unit.
        attr_accessor :creation_stamp

        # Creation time of the organizational unit.
        attr_accessor :creation_time

        # Modification stamp of the organizational unit.
        attr_accessor :modification_stamp

        # Modification time of the organizational unit.
        attr_accessor :modification_time

        # Version of the organizational unit.
        attr_accessor :version

        # URI of the organizational unit's icon. When nil is set, the organizational unit
        # uses icon from meta artifact.
        attr_accessor :icon_uri

        # UESURI of the entity type of the organizational unit. Never nil.
        attr_accessor :entity_type_uri

        # @deprecated Always returns nil.
        attr_accessor :artifact_type
        
        attr_accessor :component_content

        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end
        
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {OrganizationalUnitAttributes#version} instead.
        def revision 
          attributes[:version]
        end

        # @deprecated Use {OrganizationalUnitAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end

        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end
        
        def component_content
        attributes[:componentContent]
        end
        
        def component_content=(val)
        attributes[:componentContent] = val
        end

      end
    end

  end
end
