require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Sheet
      class SheetVersionAttributes < UU::OS::REST::DTO

        # ID of the sheet version.
        attr_accessor :version_id

        # Code of the sheet version. Empty by default and filled only when the code differs from the version before.
        attr_accessor :code
        
        # Name of the sheet version. Empty by default and filled only when the name differs from the version before.
        attr_accessor :name
        
        # Number of the sheet version.
        attr_accessor :version

        # Normalized UESURI of the sheet.
        attr_accessor :sheet_uri

        # Description of the sheet version.
        attr_accessor :label

        # Creation time of the sheet version.
        attr_accessor :creation_time

        # Creation stamp of the sheet version.
        attr_accessor :creation_stamp
        
        def version_id 
          attributes[:versionId]
        end

        def version_id=(val) 
          attributes[:versionId] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end
        
        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end
        
        # @deprecated Use {SheetVersionAttributes#version} instead.
        def revision 
          attributes[:version]
        end
        
        # @deprecated Use {SheetVersionAttributes#version} instead.
        def revision=(val) 
          attributes[:version] = val
        end
        
        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end
        
        def sheet_uri 
          attributes[:sheetUri]
        end

        def sheet_uri=(val) 
          if val
            attributes[:sheetUri] = UU::OS::UESURI.new(val)
          else
            attributes[:sheetUri] = nil
          end
        end

        def label 
          attributes[:label]
        end

        def label=(val) 
          attributes[:label] = val
        end

        def creation_time 
          attributes[:creationTime]
        end

        def creation_time=(val) 
          attributes[:creationTime] = val
        end

        def creation_stamp 
          attributes[:creationStamp]
        end

        def creation_stamp=(val) 
          attributes[:creationStamp] = val
        end

      end
    end
  end
end
